<div align="center">
<h2>
     ChatGpt WebUI: A WebUI for ChatGpt + LangChain
</h2>
<h4>
    <img width="700" alt="teaser" src="doc/data/logo.png">
<div>
    <a href="https://pepy.tech/project/text-webui"><img src="https://pepy.tech/badge/text-webui" alt="downloads"></a>
    <a href="https://badge.fury.io/py/text-webui"><img src="https://badge.fury.io/py/text-webui.svg" alt="pypi version"></a>
</div>
</div>

This repo is a implementation of the ChatGpt + LangChain Library. It also supports WebUI for the same.

### Installation
```bash
pip install text-webui
```

### Usage
```python

```
